# coding: utf-8
import numpy as np
import sys
import matplotlib.pyplot as plt
from netCDF4 import Dataset
from matplotlib.patches import Polygon
from mpl_toolkits.basemap import Basemap
from matplotlib.colors import Normalize
import math
from matplotlib import ticker
from matplotlib.patches import Polygon
from matplotlib.collections import PatchCollection
from matplotlib.patches import PathPatch

error_bar = np.loadtxt("./inundated_area_errorbar.csv", delimiter=',')

fig = plt.figure(figsize=(14, 7))
plt.rcParams['font.sans-serif'] = 'Arial'
ax = fig.add_subplot(1, 1, 1)
clv = 1
m = Basemap(llcrnrlon=85, llcrnrlat=15, urcrnrlon=138, urcrnrlat=50, resolution='l', epsg=4326)
lon_list = np.arange(85, 139, 10)
lat_list = np.arange(15, 51, 10)
m.drawparallels(lat_list, labels=[1, 0, 0, 0], fontsize=11, linewidth=0)
m.drawmeridians(lon_list, labels=[0, 0, 0, 1], fontsize=11, linewidth=0)
m.drawcoastlines(linewidth=0.05)
m.fillcontinents(color='whitesmoke')
m.drawmapboundary(fill_color='azure')
ax = plt.gca()
ax.set_yticks(lat_list)
ax.set_xticks(lon_list)
ax.tick_params(labelcolor='none')

m.readshapefile('./cy', 'comarques', drawbounds=False)
print(m.comarques_info)
patches = []
for info, shape in zip(m.comarques_info, m.comarques):
    if info['Id'] == 0:
        patches.append(Polygon(np.array(shape), True))
ax.add_collection(PatchCollection(patches, facecolor='oldlace', edgecolor='black', linewidths=0.3, zorder=2))

m.readshapefile('./cjzy', 'comarques', drawbounds=False)
print(m.comarques_info)
patches = []
for info, shape in zip(m.comarques_info, m.comarques):
    if info['Id'] == 0:
        patches.append(Polygon(np.array(shape), True))
ax.add_collection(PatchCollection(patches, facecolor='oldlace', edgecolor='black', linewidths=0.3,  zorder=2))

m.readshapefile('./csj', 'comarques', drawbounds=False)
print(m.comarques_info)
patches = []
for info, shape in zip(m.comarques_info, m.comarques):
    if info['Id'] == 0:
        patches.append(Polygon(np.array(shape), True))
ax.add_collection(PatchCollection(patches, facecolor='oldlace', edgecolor='black', linewidths=0.3, zorder=2))

m.readshapefile('./jjj', 'comarques', drawbounds=False)
print(m.comarques_info)
patches = []
for info, shape in zip(m.comarques_info, m.comarques):
    if info['Id'] == 0:
        patches.append(Polygon(np.array(shape), True))
ax.add_collection(PatchCollection(patches, facecolor='oldlace', edgecolor='black', linewidths=0.3,  zorder=2))

m.readshapefile('./zsj', 'comarques', drawbounds=False)
print(m.comarques_info)
patches = []
for info, shape in zip(m.comarques_info, m.comarques):
    if info['Id'] == 0:
        patches.append(Polygon(np.array(shape), True))
ax.add_collection(PatchCollection(patches, facecolor='oldlace', edgecolor='black', linewidths=0.3,  zorder=2))

m.readshapefile('./gz', 'comarques', drawbounds=False)
print(m.comarques_info)
patches = []
for info, shape in zip(m.comarques_info, m.comarques):
    if info['Id'] == 0:
        patches.append(Polygon(np.array(shape), True))
ax.add_collection(PatchCollection(patches, facecolor='oldlace', edgecolor='black', linewidths=0.3,  zorder=2))

m.readshapefile('./zy', 'comarques', drawbounds=False)
print(m.comarques_info)
patches = []
for info, shape in zip(m.comarques_info, m.comarques):
    if info['Id'] == 0:
        patches.append(Polygon(np.array(shape), True))
ax.add_collection(PatchCollection(patches, facecolor='oldlace', edgecolor='black', linewidths=0.3,  zorder=2))

m.readshapefile('./boundary', 'comarques',color='k',linewidth=0.1)

ax.text(115.5, 39.7, 'BTH')
ax.text(113, 34, 'CP')
ax.text(107.5, 34.8, 'CSP')
ax.text(118.5, 30.6, 'YRD')
ax.text(113, 28.7, 'TCC')
ax.text(104.85, 29.7, 'CC')
ax.text(112.5, 22.6, 'PRD')


ax = fig.add_axes([0.65, 0.65, 0.13, 0.15], facecolor='none')
ax.text(0, 120, 'BTH')
x1 = [0]
x2 = [0.8]
x3 = [1.0, 2.0, 3.0, 4.0]
x4 = [1.2, 2.2, 3.2, 4.2]
y1 = np.array([210.0247362]) / 30
y2 = np.array([626.3537706]) / 30
y3 = np.array([269.3117189, 286.5937544, 1119.491851, 1354.719556]) / 30
y4 = np.array([580.3883569, 921.4685285, 1123.81236, 912.3474543]) / 30
ax.errorbar(x1, y1, np.array(error_bar[0:2, 0:1]) / 30, fmt='co',ecolor='grey',ms=4.0,mfc='grey', mec='grey', elinewidth=2.0, capsize=3.0)
ax.errorbar(x2, y2, np.array(error_bar[0:2, 1:2]) / 30, fmt='co',ecolor='lightskyblue',ms=4.0,mfc='lightskyblue',mec='lightskyblue',elinewidth=2.0, capsize=3.0)
ax.errorbar(x3, y3, np.array(error_bar[0:2, 2:6]) / 30, fmt='co',ecolor='gold',ms=4.0, mfc='gold', mec='gold',elinewidth=2.0, capsize=3.0)
ax.errorbar(x4, y4, np.array(error_bar[0:2, 6:10]) / 30, fmt='co',ecolor='lightcoral',ms=4.0, mfc='lightcoral',mec='lightcoral',elinewidth=2.0, capsize=3.0)
ax.set_xticks([0, 1, 2, 3, 4])
ax.set_xticklabels(['Hist', '1.5°C', '2°C', '2.5°C', '3°C'])

# zhongyuan
ax = fig.add_axes([0.47, 0.70, 0.13, 0.15], facecolor='none')
ax.text(0, 120, 'CP')
x1 = [0]
x2 = [0.8]
x3 = [1.0, 2.0, 3.0, 4.0]
x4 = [1.2, 2.2, 3.2, 4.2]
y1 = np.array([123.6438917]) / 30
y2 = np.array([925.4092519]) / 30
y3 = np.array([651.7543445, 654.0582679, 1181.144755, 2169.015931]) / 30
y4 = np.array([1512.397748, 1276.117599, 1459.407509, 1683.400067]) / 30
ax.errorbar(x1, y1, np.array(error_bar[2:4, 0:1]) / 30, fmt='co',ecolor='grey',ms=4.0,mfc='grey', mec='grey', elinewidth=2.0, capsize=3.0)
ax.errorbar(x2, y2, np.array(error_bar[2:4, 1:2]) / 30, fmt='co',ecolor='lightskyblue',ms=4.0,mfc='lightskyblue',mec='lightskyblue',elinewidth=2.0, capsize=3.0)
ax.errorbar(x3, y3, np.array(error_bar[2:4, 2:6]) / 30, fmt='co',ecolor='gold',ms=4.0, mfc='gold', mec='gold',elinewidth=2.0, capsize=3.0)
ax.errorbar(x4, y4, np.array(error_bar[2:4, 6:10]) / 30, fmt='co',ecolor='lightcoral',ms=4.0, mfc='lightcoral',mec='lightcoral',elinewidth=2.0, capsize=3.0)
ax.set_xticks([0, 1, 2, 3, 4])
ax.set_xticklabels(['Hist', '1.5°C', '2°C', '2.5°C', '3°C'])

# guanzhong
ax = fig.add_axes([0.28, 0.46, 0.13, 0.15], facecolor='none')
ax.text(0, 9, 'CSP')
x1 = [0]
x2 = [0.8]
x3 = [1.0, 2.0, 3.0, 4.0]
x4 = [1.2, 2.2, 3.2, 4.2]
y1 = np.array([21.70427553]) / 30
y2 = np.array([40.8847981]) / 30
y3 = np.array([55.85906572, 38.36104513, 34.49129058, 117.270388]) / 30
y4 = np.array([101.4548694, 117.4386382, 92.20110847, 117.4386382]) / 30
ax.errorbar(x1, y1, np.array(error_bar[4:6, 0:1]) / 30, fmt='co',ecolor='grey',ms=4.0,mfc='grey', mec='grey', elinewidth=2.0, capsize=3.0)
ax.errorbar(x2, y2, np.array(error_bar[4:6, 1:2]) / 30, fmt='co',ecolor='lightskyblue',ms=4.0,mfc='lightskyblue',mec='lightskyblue',elinewidth=2.0, capsize=3.0)
ax.errorbar(x3, y3, np.array(error_bar[4:6, 2:6]) / 30, fmt='co',ecolor='gold',ms=4.0, mfc='gold', mec='gold',elinewidth=2.0, capsize=3.0)
ax.errorbar(x4, y4, np.array(error_bar[4:6, 6:10]) / 30, fmt='co',ecolor='lightcoral',ms=4.0, mfc='lightcoral',mec='lightcoral',elinewidth=2.0, capsize=3.0)
ax.set_xticks([0, 1, 2, 3, 4])
ax.set_xticklabels(['Hist', '1.5°C', '2°C', '2.5°C', '3°C'])

# changsanjiao
ax = fig.add_axes([0.66, 0.42, 0.13, 0.15], facecolor='none')
ax.text(0, 180, 'YRD')
x1 = [0]
x2 = [0.8]
x3 = [1.0, 2.0, 3.0, 4.0]
x4 = [1.2, 2.2, 3.2, 4.2]
y1 = np.array([160.5579156]) / 30
y2 = np.array([1352.09383]) / 30
y3 = np.array([1685.858114, 1243.936649, 2867.585024, 2647.656818]) / 30
y4 = np.array([1979.870117, 2049.823807, 3239.552799, 4295.311441]) / 30
ax.errorbar(x1, y1, np.array(error_bar[6:8, 0:1]) / 30, fmt='co',ecolor='grey',ms=4.0,mfc='grey', mec='grey', elinewidth=2.0, capsize=3.0)
ax.errorbar(x2, y2, np.array(error_bar[6:8, 1:2]) / 30, fmt='co',ecolor='lightskyblue',ms=4.0,mfc='lightskyblue',mec='lightskyblue',elinewidth=2.0, capsize=3.0)
ax.errorbar(x3, y3, np.array(error_bar[6:8, 2:6]) / 30, fmt='co',ecolor='gold',ms=4.0, mfc='gold', mec='gold',elinewidth=2.0, capsize=3.0)
ax.errorbar(x4, y4, np.array(error_bar[6:8, 6:10]) / 30, fmt='co',ecolor='lightcoral',ms=4.0, mfc='lightcoral',mec='lightcoral',elinewidth=2.0, capsize=3.0)
ax.set_xticks([0, 1, 2, 3, 4])
ax.set_xticklabels(['Hist', '1.5°C', '2°C', '2.5°C', '3°C'])

# changjiangzhongyou
ax = fig.add_axes([0.65, 0.18, 0.13, 0.15], facecolor='none')
ax.text(0, 90, 'TCC')
x1 = [0]
x2 = [0.8]
x3 = [1.0, 2.0, 3.0, 4.0]
x4 = [1.2, 2.2, 3.2, 4.2]
y1 = np.array([32.25766066]) / 30
y2 = np.array([674.1347052]) / 30
y3 = np.array([186.4896007, 616.1717212, 1397.663953, 1490.656741]) /30
y4 = np.array([685.727302, 795.3529457, 1377.250902, 1601.038423]) / 30
ax.errorbar(x1, y1, np.array(error_bar[8:10, 0:1]) / 30, fmt='co',ecolor='grey',ms=4.0,mfc='grey', mec='grey', elinewidth=2.0, capsize=3.0)
ax.errorbar(x2, y2, np.array(error_bar[8:10, 1:2]) / 30, fmt='co',ecolor='lightskyblue',ms=4.0,mfc='lightskyblue',mec='lightskyblue',elinewidth=2.0, capsize=3.0)
ax.errorbar(x3, y3, np.array(error_bar[8:10, 2:6]) / 30, fmt='co',ecolor='gold',ms=4.0, mfc='gold', mec='gold',elinewidth=2.0, capsize=3.0)
ax.errorbar(x4, y4, np.array(error_bar[8:10, 6:10]) / 30, fmt='co',ecolor='lightcoral',ms=4.0, mfc='lightcoral',mec='lightcoral',elinewidth=2.0, capsize=3.0)
ax.set_xticks([0, 1, 2, 3, 4])
ax.set_xticklabels(['Hist', '1.5°C', '2°C', '2.5°C', '3°C'])

# chengyu
ax = fig.add_axes([0.28, 0.22, 0.13, 0.15], facecolor='none')
ax.text(0, 22, 'CC')
x1 = [0]
x2 = [0.8]
x3 = [1.0, 2.0, 3.0, 4.0]
x4 = [1.2, 2.2, 3.2, 4.2]
y1 = np.array([6.137517904]) / 30
y2 = np.array([270.1842121]) / 30
y3 = np.array([116.079143, 129.4215732, 249.7702938, 290.8649789]) / 30
y4 = np.array([181.1902025, 343.434154, 243.8996245, 458.4459026]) / 30
ax.errorbar(x1, y1, np.array(error_bar[10:12, 0:1]) / 30, fmt='co',ecolor='grey',ms=4.0,mfc='grey', mec='grey', elinewidth=2.0, capsize=3.0)
ax.errorbar(x2, y2, np.array(error_bar[10:12, 1:2]) / 30, fmt='co',ecolor='lightskyblue',ms=4.0,mfc='lightskyblue',mec='lightskyblue',elinewidth=2.0, capsize=3.0)
ax.errorbar(x3, y3, np.array(error_bar[10:12, 2:6]) / 30, fmt='co',ecolor='gold',ms=4.0, mfc='gold', mec='gold',elinewidth=2.0, capsize=3.0)
ax.errorbar(x4, y4, np.array(error_bar[10:12, 6:10]) / 30, fmt='co',ecolor='lightcoral',ms=4.0, mfc='lightcoral',mec='lightcoral',elinewidth=2.0, capsize=3.0)
ax.set_xticks([0, 1, 2, 3, 4])
ax.set_xticklabels(['Hist', '1.5°C', '2°C', '2.5°C', '3°C'])

# zhusanjiao
ax = fig.add_axes([0.47, 0.150, 0.13, 0.15], facecolor='none')
ax.text(0, 170, 'PRD')
x1 = [0]
x2 = [0.8]
x3 = [1.0, 2.0, 3.0, 4.0]
x4 = [1.2, 2.2, 3.2, 4.2]
y1 = np.array([35.14413837]) / 30
y2 = np.array([2088.372838]) / 30
y3 = np.array([973.8981422, 375.3213752, 1344.263293, 2509.651933]) / 30
y4 = np.array([1614.377536, 2137.935084, 2917.864617, 4204.455477]) / 30
ax.errorbar(x1, y1, np.array(error_bar[12:14, 0:1]) / 30, fmt='co',ecolor='grey',ms=4.0,mfc='grey', mec='grey', elinewidth=2.0, capsize=3.0)
ax.errorbar(x2, y2, np.array(error_bar[12:14, 1:2]) / 30, fmt='co',ecolor='lightskyblue',ms=4.0,mfc='lightskyblue',mec='lightskyblue',elinewidth=2.0, capsize=3.0)
ax.errorbar(x3, y3, np.array(error_bar[12:14, 2:6]) / 30, fmt='co',ecolor='gold',ms=4.0, mfc='gold', mec='gold',elinewidth=2.0, capsize=3.0)
ax.errorbar(x4, y4, np.array(error_bar[12:14, 6:10]) / 30, fmt='co',ecolor='lightcoral',ms=4.0, mfc='lightcoral',mec='lightcoral',elinewidth=2.0, capsize=3.0)
ax.set_xticks([0, 1, 2, 3, 4])
ax.set_xticklabels(['Hist', '1.5°C', '2°C', '2.5°C', '3°C'])

# all
ax = fig.add_axes([0.221, 0.67, 0.19, 0.21], facecolor='linen')
ax.set_xticks([])
ax.set_yticks([])
ax.spines['bottom'].set_linewidth(0)
ax.spines['left'].set_linewidth(0)
ax.spines['right'].set_linewidth(0)
ax.spines['top'].set_linewidth(0)
ax = fig.add_axes([0.27, 0.70, 0.13, 0.15], facecolor='none')
ax.text(0, 500, 'ALL')
x1 = [0]
x2 = [0.8]
x3 = [1.0, 2.0, 3.0, 4.0]
x4 = [1.2, 2.2, 3.2, 4.2]
y1 = np.array([684.8379852]) / 30
y2 = np.array([5208.189957]) / 30
y3 = np.array([3880.764711, 3735.21745, 8052.732301, 11266.37008]) / 30
y4 = np.array([6388.855719, 7305.000097, 9427.311043, 13670.62131]) / 30
ax.errorbar(x1, y1, np.array(error_bar[14:16, 0:1]) / 30, fmt='co',ecolor='grey',ms=4.0,mfc='grey', mec='grey', elinewidth=2.0, capsize=3.0, label='Hist')
ax.errorbar(x2, y2, np.array(error_bar[14:16, 1:2]) / 30, fmt='co',ecolor='lightskyblue',ms=4.0,mfc='lightskyblue',mec='lightskyblue',elinewidth=2.0, capsize=3.0, label='SSP1-2.6')
ax.errorbar(x3, y3, np.array(error_bar[14:16, 2:6]) / 30, fmt='co',ecolor='gold',ms=4.0, mfc='gold', mec='gold',elinewidth=2.0, capsize=3.0, label='SSP3-7.0')
ax.errorbar(x4, y4, np.array(error_bar[14:16, 6:10]) / 30, fmt='co',ecolor='lightcoral',ms=4.0, mfc='lightcoral',mec='lightcoral',elinewidth=2.0, capsize=3.0, label='SSP5-8.5')
ax.set_xticks([0, 1, 2, 3, 4])
ax.set_xticklabels(['Hist', '1.5°C', '2°C', '2.5°C', '3°C'])

font2 = {'family': 'Arial'}
ax.set_ylabel('Inundated areas(km²)', font2)
ax.legend(bbox_to_anchor=(-0.3, -3.4), loc='upper left', ncol=2, fontsize=8)
plt.savefig("./chn_urban_inundated_area_jiazhu_new.pdf", dpi=1200)